import 'dart:convert';

import 'package:flutter/material.dart';

import '../../../models/counts_by_hour.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';
import '../../../ui/widgets/main_screen/counts_by_hour_content.dart';

class ChartCountsByHourCard extends StatelessWidget {
  const ChartCountsByHourCard({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = 21;
    late Future<CountsByHourData> futureCountsByHour =
        ScrobblesApi.fetchCountsByHour(daysCount);

    return FutureBuilder<CountsByHourData>(
      future: futureCountsByHour,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return Card(
          elevation: 2,
          shadowColor: Theme.of(context).colorScheme.shadow,
          color: Theme.of(context).colorScheme.surface,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(12),
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.all(12.0),
            child: ChartCountsByHourCardContent(
              daysCount: daysCount,
              chartData: snapshot.hasData
                  ? CountsByHourData.fromJson(jsonDecode(snapshot.data.toString()))
                  : CountsByHourData.createEmpty(),
              isLoading: !snapshot.hasData,
            ),
          ),
        );
      },
    );
  }
}
